@@ -140,8 +140,9 @@ _FP_memdup (void *ptr, int len)
  * case-insensitive compare
  */
 
+#ifndef FP_stricmp
 int TOOLEXPORT
-_FP_stricmp (char *str1, char *str2)
+_FP_stricmp (const char *str1, const char *str2)
 {
   if (str1==NULL || str2==NULL)
     return -1;
@@ -154,9 +155,11 @@ _FP_stricmp (char *str1, char *str2)
   }
   return (tolower (*str1) - tolower (*str2));
 }
+#endif
 
+#ifndef FP_strnicmp
 int TOOLEXPORT
-_FP_strnicmp (char *str1, char *str2, int count)
+_FP_strnicmp (const char *str1, const char *str2, int count)
 {
   if (str1==NULL || str2==NULL)
     return -1;
@@ -170,33 +173,7 @@ _FP_strnicmp (char *str1, char *str2, int count)
   }
   return count ? (tolower (*str1) - tolower (*str2)) : 0;
 }
-
-/*
- * autoconf says this function might be a compatibility problem
- */
-
-char * TOOLEXPORT
-_FP_strstr (char *str1, char *str2)
-{
-  char *ptr1, *ptr2;
-
-  if (str1==NULL)
-    return NULL;
-  if (str2==NULL)
-    return str1;
-
-  while (*(ptr1=str1)) {
-    for (ptr2=str2;
-	 *ptr1 && *ptr2 && *ptr1==*ptr2;
-	 ptr1++, ptr2++)
-      /* empty loop */ ;
-
-    if (*ptr2 == '\0')
-      return str1;
-    str1++;
-  }
-  return NULL;
-}
+#endif
 
 char * TOOLEXPORT
 _FP_strpbrk (char *str, char *accept)
@@ -257,6 +234,7 @@ _FP_strtok (char *str1, char *str2)
  * case insensitive strstr.
  */
 
+#ifndef FP_stristr
 char * TOOLEXPORT
 _FP_stristr (char *str1, char *str2)
 {
@@ -279,6 +257,7 @@ _FP_stristr (char *str1, char *str2)
   }
   return NULL;
 }
+#endif
 
 /*
  * Nice fake of the real (non-standard) one
@@ -431,80 +410,54 @@ _FP_cutdir (char *filename)
 
 /*
  * My own fgets function. It handles all kinds of line terminators
- * properly: LF (Unix), CRLF (DOS) and CR (Mac). In all cases, the
- * terminator is replaced by a single LF
+ * properly: LF (Unix), CRLF (DOS) and CR (Mac).
  */
-
+/* (schmorp) the buffer is always written to, and no LF is stored at the end */
+/* also, if the buffer is too short, the remaining line is skipped */
 char * TOOLEXPORT
 _FP_fgets (char *buf, int n, FILE *stream)
 {
-  char *obp = buf;
-  int c;
+  char *ptr = buf;
+  char *end = buf + n - 1;
 
   /* shield against buffer overflows caused by "255 - bytes_left"-kind of bugs when bytes_left > 255 */
   if (n <= 0)
-    return NULL;
+    return 0;
 
-  if (feof (stream))
-    return NULL;
+  for (;;)
+    {
+      int c = FP_fgetc (stream);
 
-  while (--n && !feof (stream)) {
-    if ((c = fgetc (stream)) == EOF) {
-      if (ferror (stream))
-	return NULL;
-      else {
-	if (obp == buf)
-	  return NULL;
-	*buf = '\0';
-	return obp;
-      }
+      if (ecb_expect_false (c <= '\015')) /* EOF is < 0x20, too */
+        {
+          /* ctlchar */
+
+          if (c == '\012')
+            /* LF, nothing following */
+            break;
+          else if (c == '\015')
+            {
+              /* CR, possibly CRLF, skip following LF */
+              c = FP_fgetc (stream);
+
+              if (c != '\012') /* CR LF? */
+                ungetc (c, stream);
+
+              break;
+            }
+          else if (c == EOF)
+            {
+              *ptr = 0;
+              return 0;
+            }
+        }
+
+      *ptr = c;
+      ptr += ptr < end; /* this is hopefully branch-free, and fast */
     }
-    if (c == '\015') { /* CR */
-      /*
-       * Peek next character. If it's no LF, push it back.
-       * ungetc(EOF, stream) is handled correctly according
-       * to the manual page
-       */
-      if ((c = fgetc (stream)) != '\012')
-	if (!feof (stream))
-	  ungetc (c, stream);
-      *buf++ = '\012';
-      *buf   = '\0';
-      return obp;
-    }
-    else if (c == '\012') { /* LF */
-      *buf++ = '\012';
-      *buf   = '\0';
-      return obp;
-    }
-    /*
-     * just another standard character
-     */
-    *buf++ = c;
-  }
 
-  /*
-   * n-1 characters already transferred
-   */
-
-  *buf = '\0';
-
-  /*
-   * If a line break is coming up, read it
-   */
-
-  if (!feof (stream)) {
-    if ((c = fgetc (stream)) == '\015' && !feof (stream)) {
-      if ((c = fgetc (stream)) != '\012' && !feof (stream)) {
-	ungetc (c, stream);
-      }
-    }
-    else if (c != '\012' && !feof (stream)) {
-      ungetc (c, stream);
-    }
-  }
-
-  return obp;
+  *ptr = 0;
+  return buf;
 }
 
 /*
