@@ -69,7 +69,7 @@
 
 #define UUPERCENT(a,b)	((int) ((unsigned long)(a) / \
 				(((unsigned long)(b)/100)+1)))
-
+     
 /*
  * Make the Busy Callback easier. The macro returns true if the BusyCallback
  * wants us to terminate.
@@ -142,13 +142,13 @@ typedef struct _fileread {
   char *origin;		/* Whole 'From:' line */
   char *mimeid;		/* the ID for Mime-encoded files */
   char *mimetype;	/* Content-Type */
+  int   mode;		/* Mode of File (from 'begin') */
   int   begin;		/* begin detected */
   int   end;		/* end detected */
+  int   flags;		/* associated flags */
   long  yefilesize;     /* the yencode file size, or 0 */
 
-  uint16_t mode;	/* Mode of File (from 'begin') */
-  uint8_t flags;	/* associated flags */
-  uint8_t uudet;	/* valid encoded data. value indicates encoding */
+  int   uudet;		/* valid encoded data. value indicates encoding */
   int   partno;		/* Mime-files have a part number within */
   int   maxpno;		/* ... plus the total number of parts   */
 
@@ -165,14 +165,14 @@ typedef struct _fileread {
  **/
 
 typedef struct _uufile {
-  struct _uufile *NEXT;
   char     *filename;
   char     *subfname;
   char     *mimeid;
   char     *mimetype;
+  int       partno;
   fileread *data;
   long      yefilesize;
-  int       partno;
+  struct _uufile *NEXT;
 } uufile;
 
 extern void *uu_MsgCBArg;
@@ -302,7 +302,7 @@ fileread *	ScanPart 		(FILE *, char *, int *);
 
 int		UUbhdecomp		(char *, char *,
 				         char *, int *,
-				         size_t, size_t,
+				         size_t, size_t, 
 				         size_t *);
 size_t		UUbhwrite		(char *, size_t, size_t, FILE *);
 
