@@ -81,6 +81,8 @@
 #include <fptools.h>
 #include <uustring.h>
 
+#include "safealloc.c"
+
 char * uulib_id = "$Id$";
 
 #ifdef SYSTEM_WINDLL
@@ -255,8 +257,8 @@ static allomap toallocate[] = {
   { &uuscan_pvvalue,     300 },  /* from uuscan.c:ParseValue() */
   { &uuscan_phtext,      300 },  /* from uuscan.c:ParseHeader() */
   { &uuscan_sdline,     1025 },  /* from uuscan.c:ScanData(), +1 for UURepairData */
-  { &uuscan_sdbhds1,     300 },
-  { &uuscan_sdbhds2,     300 },
+  { &uuscan_sdbhds1,    1300 },  /* 1024 for line in UUScan + 256 potential overhead UUDecodeLine */
+  { &uuscan_sdbhds2,    1300 },  /* 1024 for line in UUScan + 256 potential overhead UUDecodeLine */
   { &uuscan_spline,     1024 },  /* from uuscan.c:ScanPart() */
   { &uuutil_bhwtmp,      300 },  /* from uuutil.c:UUbhwrite() */
   { NULL, 0 }
@@ -275,7 +277,7 @@ UUMessage (va_alist)
   va_dcl
 #endif
 {
-  char *msgptr;
+  int msgofs;
 #if defined(STDC_HEADERS) || defined(HAVE_STDARG_H)
   va_list ap;
 
@@ -293,16 +295,16 @@ UUMessage (va_alist)
 #endif
 
   if (uu_debug) {
-    sprintf (uulib_msgstring, "%s(%d): %s", file, line, msgnames[level]);
-    msgptr = uulib_msgstring + strlen (uulib_msgstring);
+    snprintf (uulib_msgstring, 1024,  "%s(%d): %s", file, line, msgnames[level]);
+    msgofs = strlen (uulib_msgstring);
   }
   else {
-    sprintf (uulib_msgstring, "%s", msgnames[level]);
-    msgptr = uulib_msgstring + strlen (uulib_msgstring);
+    snprintf (uulib_msgstring, 1024, "%s", msgnames[level]);
+    msgofs = strlen (uulib_msgstring);
   }
 
   if (uu_MsgCallback && (level>UUMSG_NOTE || uu_verbose)) {
-    vsprintf (msgptr, format, ap);
+    vsnprintf (uulib_msgstring + msgofs, 1024 - msgofs, format, ap);
 
     (*uu_MsgCallback) (uu_MsgCBArg, uulib_msgstring, level);
   }
@@ -396,13 +398,13 @@ UUInitialize (void)
     *(aiter->ptr) = NULL;
 
   for (aiter=toallocate; aiter->ptr; aiter++) {
-    if ((*(aiter->ptr) = (char *) malloc (aiter->size)) == NULL) {
+    if ((*(aiter->ptr) = (char *) safe_alloc (aiter->size)) == NULL) {
       /*
        * oops. we may not print a message here, because we need these
        * areas (uulib_msgstring) in UUMessage()
        */
       for (aiter=toallocate; aiter->ptr; aiter++) {
-	_FP_free (*(aiter->ptr));
+	safe_free (*(aiter->ptr), aiter->size);
       }
       return UURET_NOMEM;
     }
@@ -1359,7 +1361,7 @@ UUCleanUp (void)
    */
 
   for (aiter=toallocate; aiter->ptr; aiter++) {
-    _FP_free (*(aiter->ptr));
+    safe_free (*(aiter->ptr), aiter->size);
     *(aiter->ptr) = NULL;
   }
 
