@@ -182,7 +182,7 @@ static char *
 ScanHeaderLine (FILE *datei, char *initial)
 {
   char *ptr=uuscan_shlline;
-  char *ptr2, *p1, *p2, *p3;
+  char *ptr2, *p2, *p3;
   int llength, c;
   long curpos;
 
@@ -269,10 +269,10 @@ ScanHeaderLine (FILE *datei, char *initial)
 
     if (*ptr == '=' && *(ptr+1) == '?') {
       /*
-       * Let p1 point to the charset, look for next question mark
+       * Let p2 point to the charset, look for next question mark
        */
 
-      p1 = p2 = ptr+2;
+      p2 = ptr+2;
 
       while (*p2 && *p2 != '?') {
 	p2++;
@@ -817,8 +817,9 @@ ScanData (FILE *datei, char *fname, int *errcode,
 	}
 	if ((ptr = strchr (line, ':')) != NULL) {
 	  ptr++;
-	  while (isspace (*ptr)) ptr++; p2 = ptr;
-	  while (!isspace (*p2) && *p2 != ';') p2++;
+	  while (isspace (*ptr)) ptr++;
+          p2 = ptr;
+	  while (*p2 && !isspace (*p2) && *p2 != ';') p2++;
 	  c = *p2; *p2 = '\0';
 	  if (p2 != ptr) {
 	    _FP_free (result->mimetype);
@@ -985,6 +986,9 @@ ScanData (FILE *datei, char *fname, int *errcode,
 	  result->begin = 1;
 	}
 
+        if ((ptr = _FP_strstr (line, " total=")))
+	  result->maxpno = atoi (ptr + 7);
+
 	if (_FP_fgets (line, 1024, datei) == NULL) {
 	  break;
 	}
@@ -1014,7 +1018,10 @@ ScanData (FILE *datei, char *fname, int *errcode,
 
     if (strncmp (line, "=yend ", 6) == 0 &&
 	result->uudet == YENC_ENCODED) {
-      if (yepartends == 0 || yepartends >= result->yefilesize) {
+      if (yepartends == 0) {
+        if (!result->maxpno || result->maxpno == result->partno)
+          result->end = 1;
+      } else if (yepartends >= result->yefilesize) {
 	result->end = 1;
       }
 #if 0
@@ -1096,7 +1103,7 @@ ScanData (FILE *datei, char *fname, int *errcode,
 	if (vflag == BH_ENCODED && bhnf == 0 && result->filename == NULL) {
 	  if (bhdsp == bhds2 ||
 	      ((bhdsp-bhds2) <= (int) bhds2[0] &&
-	       (bhdsp-bhds2) <  256)) { 
+	       (bhdsp-bhds2) <  256)) {
 	    dcc = UUDecodeLine (line, bhds1, BH_ENCODED);
 	    UUbhdecomp (bhds1, bhdsp, &bhl, &bhrpc,
 			dcc, 256-(bhdsp-bhds2), &bhopc);
